gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-wallet-core] branch master updated: taler-wallet-core ios compati


From: gnunet
Subject: [taler-wallet-core] branch master updated: taler-wallet-core ios compatibility
Date: Fri, 30 Jul 2021 23:35:51 +0200

This is an automated email from the git hooks/post-receive script.

jonathan-buchanan pushed a commit to branch master
in repository wallet-core.

The following commit(s) were added to refs/heads/master by this push:
     new 4f88d7f8 taler-wallet-core ios compatibility
4f88d7f8 is described below

commit 4f88d7f89669cf3fc26254c6058aa06256cc5669
Author: Jonathan Buchanan <jonathan.russ.buchanan@gmail.com>
AuthorDate: Fri Jul 30 17:35:38 2021 -0400

    taler-wallet-core ios compatibility
---
 .../taler-wallet-core/src/crypto/workers/nodeThreadWorker.ts | 12 ++++++++----
 packages/taler-wallet-core/src/wallet.ts                     |  2 +-
 2 files changed, 9 insertions(+), 5 deletions(-)

diff --git a/packages/taler-wallet-core/src/wallet.ts 
b/packages/taler-wallet-core/src/wallet.ts
index e6d541e9..3c3da3ce 100644
--- a/packages/taler-wallet-core/src/wallet.ts
+++ b/packages/taler-wallet-core/src/wallet.ts
@@ -637,7 +637,7 @@ async function dispatchRequestInternal(
   operation: string,
   payload: unknown,
 ): Promise<Record<string, any>> {
-  if (ws.initCalled && operation !== "initWallet") {
+  if (!ws.initCalled && operation !== "initWallet") {
     throw Error(
       `wallet must be initialized before running operation ${operation}`,
     );

diff --git a/packages/taler-wallet-core/src/crypto/workers/nodeThreadWorker.ts 
b/packages/taler-wallet-core/src/crypto/workers/nodeThreadWorker.ts
index 90016ab4..3f7f9e17 100644
--- a/packages/taler-wallet-core/src/crypto/workers/nodeThreadWorker.ts
+++ b/packages/taler-wallet-core/src/crypto/workers/nodeThreadWorker.ts
@@ -28,11 +28,15 @@ const logger = new Logger("nodeThreadWorker.ts");
 const f = __filename;
 
 const workerCode = `
   // Try loading the glue library for Android
   try {
     require("akono");
   } catch (e) {
-    // Probably we're not on Android ...
+    try {
+      require("iono");
+    } catch (e2) {
+      // Probably we're not on embedded ...
+    }
   }
   const worker_threads = require('worker_threads');
   const parentPort = worker_threads.parentPort;
@@ -44,9 +48,9 @@ const workerCode = `
   }
   if (!tw) {
     try {
-      tw = require("@gnu-taler/taler-wallet-android");
+      tw = require("@gnu-taler/taler-wallet-embedded");
     } catch (e) {
-      console.warn("could not load taler-wallet-android either");
+      console.warn("could not load taler-wallet-embedded either");
       throw e;
     }
   }
@@ -28,11 +28,15 @@ const logger = new Logger("nodeThreadWorker.ts");
 
 const workerCode = `
-  // Try loading the glue library for Android
+  // Try loading the glue library for embedded
   try {
     require("akono");
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]